.. _introduction:

============
Introduction
============

Introduction to basic design and usage of different modules in KLIFF. This should ensure
that you understand how to use individual KLIFF modules for your research.

.. toctree::
   :maxdepth: 1

   introduction/Dataset
   introduction/Trainer_and_kim
   introduction/ConfigurationTransforms
   introduction/Trainer_dnn
   introduction/Trainer_gnn
